@@ -16,8 +16,8 @@ use crate::{
 };
 
 use super::{
-    int::{IntRepr, LeU32, LeU64},
     RawConst, RawInt,
+    int::{IntRepr, LeU32, LeU64},
 };
 
 /// Sequence of serialized values (length serialized as `U`).
@@ -25,7 +25,7 @@ use super::{
 #[repr(transparent)]
 pub struct Seq<'a, T: Clone, U>(pub Cow<'a, [T]>, PhantomData<U>);
 
-impl<'a, T: Clone, U> Deref for Seq<'a, T, U> {
+impl<T: Clone, U> Deref for Seq<'_, T, U> {
     type Target = [T];
 
     fn deref(&self) -> &Self::Target {
@@ -68,7 +68,7 @@ impl<'a, T: Clone, U> Seq<'a, T, U> {
     }
 }
 
-impl<'a, T: Clone, U> Default for Seq<'a, T, U> {
+impl<T: Clone, U> Default for Seq<'_, T, U> {
     fn default() -> Self {
         Seq::new(Vec::new())
     }
@@ -138,7 +138,7 @@ macro_rules! impl_seq_repr {
                 let mut seq = Vec::with_capacity(len);
                 match T::SIZE {
                     Some(count) => {
-                        let mut buf: ParseBuf = buf.parse(count * len)?;
+                        let mut buf: ParseBuf<'_> = buf.parse(count * len)?;
                         for _ in 0..len {
                             seq.push(buf.parse(())?);
                         }
@@ -185,7 +185,7 @@ impl<'a, T: IntRepr, U> RawSeq<'a, T, U> {
     }
 }
 
-impl<'a, T: IntRepr, U> RawSeq<'a, T, U>
+impl<T: IntRepr, U> RawSeq<'_, T, U>
 where
     T: Copy,
     U: TryFrom<T::Primitive>,
